--AH:ScriptId=7f7a7645-4732-498a-85a0-4345b996e6bf;2952
DECLARE @SQL NVARCHAR(MAX)

SET @SQL = 'ALTER DATABASE ' + QUOTENAME(DB_NAME()) + ' SET AUTO_CLOSE OFF'
EXEC sp_executesql @SQL

SET @SQL = 'ALTER DATABASE ' + QUOTENAME(DB_NAME()) + ' COLLATE SQL_Latin1_General_CP1_CI_AS '
EXEC sp_executesql @SQL
GO

CREATE ROLE [OtterUser_Role] AUTHORIZATION [dbo]
GO

CREATE TYPE YNINDICATOR FROM CHAR(1)
GO

CREATE RULE YNINDICATOR_Domain
    AS @Ind COLLATE Latin1_General_BIN IN ('Y','N')
GO

CREATE TYPE USERNAME FROM NVARCHAR(255)
GO

EXEC sp_bindrule 'YNINDICATOR_Domain', 'YNINDICATOR'
GO

CREATE TABLE [Environments] (
  
  [Environment_Id] INT IDENTITY(1,1) NOT NULL
    CONSTRAINT [PK__Environments]
	PRIMARY KEY ([Environment_Id]),

  [Environment_Name] NVARCHAR(50) NOT NULL
    CONSTRAINT [UQ__Environments__Environment_Name]
	UNIQUE ([Environment_Name]),

  [Parent_Environment_Id] INT NULL
    CONSTRAINT [FK__Environments__Environments]
	FOREIGN KEY ([Parent_Environment_Id])
	REFERENCES [Environments] ([Environment_Id])

)

GO

CREATE TABLE [Hosts] (
  
  [Host_Id] INT IDENTITY(1,1) NOT NULL
    CONSTRAINT [PK__Hosts]
	PRIMARY KEY ([Host_Id]),

  [Host_Name] NVARCHAR(50) NOT NULL
    CONSTRAINT [UQ__Hosts__Host_Name]
	UNIQUE ([Host_Name]),

  [Host_Configuration] XML NOT NULL
)

GO

CREATE TABLE [Rafts] (
  
  [Raft_Id] INT IDENTITY(1,1) NOT NULL
    CONSTRAINT [PK__Rafts]
	PRIMARY KEY ([Raft_Id]),

  [Raft_Name] NVARCHAR(50) NOT NULL
    CONSTRAINT [UQ__Rafts__Raft_Name]
	UNIQUE ([Raft_Name]),

  [Environment_Id] INT NULL
    CONSTRAINT [FK__Rafts__Environments]
	FOREIGN KEY ([Environment_Id])
	REFERENCES [Environments] ([Environment_Id])
	ON DELETE SET NULL,

  [Raft_Configuration] XML NOT NULL
)

CREATE TABLE [RaftContents] (
  [Raft_Id] INT  NOT NULL
    CONSTRAINT [PK__RaftContents]
	PRIMARY KEY ([Raft_Id]),
  
  CONSTRAINT [FK__RaftContents__Rafts]
	FOREIGN KEY ([Raft_Id])
	REFERENCES [Rafts] ([Raft_Id])
	ON DELETE CASCADE,

  [Content_Bytes] VARBINARY(MAX) NOT NULL,
)

GO

CREATE TABLE [Servers] 
(
    [Server_Id] INT IDENTITY(1,1) NOT NULL
        CONSTRAINT [PK__Servers]
	    PRIMARY KEY ([Server_Id]),

    [Host_Id] INT NULL
        CONSTRAINT [FK__Servers__Hosts]
        FOREIGN KEY ([Host_Id])
        REFERENCES [Hosts] ([Host_Id]),

    [Raft_Id] INT NULL
        CONSTRAINT [FK__Servers__Rafts]
        FOREIGN KEY ([Raft_Id])
        REFERENCES [Rafts] ([Raft_Id])
        ON DELETE SET NULL,

    [ServerStatus_Code] CHAR(5)
        CONSTRAINT [CK__Servers__ServerStatus_Code_Domain]
        CHECK ([ServerStatus_Code] IN ('READY', 'ERROR', 'UPDAT', 'UNKWN')),

    [Server_Name] NVARCHAR(50) NOT NULL
        CONSTRAINT [UQ__Servers__Server_Name]
        UNIQUE ([Server_Name]),

    [RoutineExecutionType_Code] CHAR(1) NOT NULL
        CONSTRAINT [CK__Servers__RoutineExecutionType_Code_Domain]
        CHECK ([RoutineExecutionType_Code] IN ('C','E','N')),

    [Agent_Configuration] XML NOT NULL
  
)

GO

CREATE TABLE [HostServers] (
  
  [Host_Id] INT NOT NULL
    CONSTRAINT [FK__HostServers__Hosts]
	FOREIGN KEY ([Host_Id])
	REFERENCES [Hosts] ([Host_Id]),

  [UniqueId_Text] NVARCHAR(50) NOT NULL,
  CONSTRAINT [PK__HostServers]
  PRIMARY KEY ([Host_Id], [UniqueId_Text]),

  [Display_Name] NVARCHAR(50) NOT NULL,

  [StatusName_Text] NVARCHAR(50) NOT NULL,

  [Running_Indicator] CHAR(1) NOT NULL,

  [Server_Id] INT NULL
    CONSTRAINT [FK__Servers__HostServers]
	FOREIGN KEY ([Server_Id])
	REFERENCES [Servers] ([Server_Id]) ON DELETE SET NULL,

)

GO

CREATE TABLE [ServerRoles] (
  
  [ServerRole_Id] INT IDENTITY(1,1) NOT NULL
    CONSTRAINT [PK__ServerRoles]
	PRIMARY KEY ([ServerRole_Id]),

  [ServerRole_Name] NVARCHAR(50) NOT NULL
    CONSTRAINT [UQ__ServerRoles__ServerRole_Name]
	UNIQUE ([ServerRole_Name]),

  [Raft_Id] INT NULL
    CONSTRAINT [FK__ServerRoles__Rafts]
	FOREIGN KEY ([Raft_Id])
	REFERENCES [Rafts] ([Raft_Id])
	ON DELETE SET NULL
)

GO

CREATE TABLE [EnvironmentServers] (
  
  [Environment_Id] INT NOT NULL
    CONSTRAINT [FK__EnvironmentServers__Environments]
	FOREIGN KEY ([Environment_Id])
	REFERENCES [Environments] ([Environment_Id]) ON DELETE CASCADE,

  [Server_Id] INT NOT NULL
    CONSTRAINT [FK__Servers__EnvironmentServers]
	FOREIGN KEY ([Server_Id])
	REFERENCES [Servers] ([Server_Id]) ON DELETE CASCADE,

  CONSTRAINT [PK__EnvironmentServers]
  PRIMARY KEY ([Environment_Id],[Server_Id])

)

GO

CREATE TABLE [ServerRoleServers] (
  
  [ServerRole_Id] INT NOT NULL
    CONSTRAINT [FK__ServerRoleServers__ServerRoles]
	FOREIGN KEY ([ServerRole_Id])
	REFERENCES [ServerRoles] ([ServerRole_Id]) ON DELETE CASCADE,

  [Server_Id] INT NOT NULL
    CONSTRAINT [FK__Servers__ServerRoleServers]
	FOREIGN KEY ([Server_Id])
	REFERENCES [Servers] ([Server_Id]) ON DELETE CASCADE,

  CONSTRAINT [PK__ServerRoleServers]
  PRIMARY KEY ([ServerRole_Id],[Server_Id])

)

GO

CREATE TABLE [Schedules]
(
    [Schedule_Id] INT IDENTITY(1, 1) NOT NULL,
    [Schedule_Name] NVARCHAR(50) NOT NULL,
    [Schedule_Configuration] XML NOT NULL,
    [Active_Indicator] YNINDICATOR NOT NULL,    

    CONSTRAINT [PK__Schedules] PRIMARY KEY ([Schedule_Id])
)

GO

CREATE TABLE [Jobs]
(
    [Job_Id] INT IDENTITY(1, 1) NOT NULL,
    [JobType_Code] CHAR(1) NOT NULL,
    [Plan_Name] NVARCHAR(1000) NULL,
    [Raft_Id] INT NOT NULL,
    [Schedule_Id] INT NULL,
    [Job_Name] NVARCHAR(50) NOT NULL,
    [JobTarget_Code] CHAR(1) NOT NULL,
    [LastRun_Date] DATETIME NULL,
    [Start_Date] DATETIME NULL,
    [Simulation_Indicator] YNINDICATOR NOT NULL,
    [JobState_Code] CHAR(1) NOT NULL,

    CONSTRAINT [CK__Jobs__JobType_Code]
         CHECK ([JobType_Code] IN ('O', 'C')),

    CONSTRAINT [CK__Jobs__JobTarget_Code]
         CHECK ([JobTarget_Code] IN ('D', 'I')),

    CONSTRAINT [CK__Jobs__JobState_Code]
         CHECK ([JobState_Code] IN ('P', 'R', 'C', 'F', 'D')),

    CONSTRAINT [CK__Jobs__ImmediateOrScheduled] 
         CHECK ([Schedule_Id] IS NULL AND [Start_Date] IS NOT NULL OR [Schedule_Id] IS NOT NULL AND [Start_Date] IS NULL),

    CONSTRAINT [CK__Jobs__CompletedDate] 
         CHECK ([JobState_Code] <> 'C' OR [LastRun_Date] IS NOT NULL),

    CONSTRAINT [CK__Jobs__Plan_Name] 
         CHECK ([Plan_Name] IS NULL AND [JobType_Code] = 'C' OR [Plan_Name] IS NOT NULL AND [JobType_Code] = 'O'),

    CONSTRAINT [CK__Jobs__ScheduledCannotBeCompleted] 
         CHECK ([Schedule_Id] IS NULL OR ([Schedule_Id] IS NOT NULL AND [JobState_Code] <> 'C')),

    CONSTRAINT [FK__Jobs__Rafts] 
               FOREIGN KEY ([Raft_Id]) 
               REFERENCES [Rafts] ([Raft_Id])
               ON DELETE CASCADE,

    CONSTRAINT [FK__Jobs__Schedules] 
               FOREIGN KEY ([Schedule_Id]) 
               REFERENCES [Schedules] ([Schedule_Id])
               ON DELETE CASCADE,

    CONSTRAINT [PK__Jobs] PRIMARY KEY ([Job_Id])
)
GO

CREATE TABLE [JobServers]
(
    [Job_Id] INT NOT NULL,
    [Server_Id] INT NOT NULL,

    CONSTRAINT [FK__JobServers__Jobs] 
               FOREIGN KEY ([Job_Id]) 
               REFERENCES [Jobs] ([Job_Id])
               ON DELETE CASCADE,

    CONSTRAINT [FK__JobServers__Servers] 
               FOREIGN KEY ([Server_Id]) 
               REFERENCES [Servers] ([Server_Id])
               ON DELETE CASCADE,

    CONSTRAINT [PK__JobServers] PRIMARY KEY ([Job_Id], [Server_Id])
)

CREATE TABLE [JobServerRoles]
(
    [Job_Id] INT NOT NULL,
    [ServerRole_Id] INT NOT NULL,

    CONSTRAINT [FK__JobServerRoles__Jobs] 
               FOREIGN KEY ([Job_Id]) 
               REFERENCES [Jobs] ([Job_Id])
               ON DELETE CASCADE,

    CONSTRAINT [FK__JobServerRoles__ServerRoles] 
               FOREIGN KEY ([ServerRole_Id]) 
               REFERENCES [ServerRoles] ([ServerRole_Id])
               ON DELETE CASCADE,

    CONSTRAINT [PK__JobServerRoles] PRIMARY KEY ([Job_Id], [ServerRole_Id])
)

CREATE TABLE [JobEnvironments]
(
    [Job_Id] INT NOT NULL,
    [Environment_Id] INT NOT NULL,

    CONSTRAINT [FK__JobEnvironments__Jobs] 
               FOREIGN KEY ([Job_Id]) 
               REFERENCES [Jobs] ([Job_Id])
               ON DELETE CASCADE,

    CONSTRAINT [FK__JobEnvironments__Environments] 
               FOREIGN KEY ([Environment_Id]) 
               REFERENCES [Environments] ([Environment_Id])
               ON DELETE CASCADE,

    CONSTRAINT [PK__JobEnvironments] PRIMARY KEY ([Job_Id], [Environment_Id])
)


GO

CREATE TABLE [Executions]
(
	[Execution_Id] INT IDENTITY(1, 1) NOT NULL
	CONSTRAINT [PK__Executions]
	PRIMARY KEY,

    [Job_Id] INT NULL
    CONSTRAINT [FK__Executions__Jobs] 
    FOREIGN KEY REFERENCES [Jobs] ([Job_Id])
    ON DELETE SET NULL,

    [Server_Id] INT NULL
    CONSTRAINT [FK__Executions__Servers] 
    FOREIGN KEY REFERENCES [Servers] ([Server_Id])
    ON DELETE CASCADE,

	[Start_Date] DATETIME NOT NULL,
	[End_Date] DATETIME NULL,

	[ExecutionStatus_Code] CHAR(1) NOT NULL
    CONSTRAINT [CK__Executions__ExecutionStatus_Code] 
         CHECK ([ExecutionStatus_Code] IN ('W', 'E', 'S')),

    [ExecutionRunState_Code] CHAR(1) NOT NULL,
    CONSTRAINT [CK__Executions__ExecutionState_Code] 
         CHECK ([ExecutionRunState_Code] IN ('P', 'X', 'C')),    

    [ExecutionMode_Code] CHAR(1) NOT NULL
	CONSTRAINT [CK__Executions__ExecutionMode_Code] 
         CHECK ([ExecutionMode_Code] IN ('C', 'E', 'X')),
    
	[Simulation_Indicator] YNINDICATOR NOT NULL,

    [DriftDetected_Indicator] YNINDICATOR NOT NULL,
)

GO

CREATE TABLE [Variables]
(
	[Variable_Id] INT IDENTITY(1,1) NOT NULL 
		CONSTRAINT [PK__Variables]
		PRIMARY KEY,

	[Server_Id] INT NULL,
	[Environment_Id] INT NULL,
	[ServerRole_Id] INT NULL,
	[Job_Id] INT NULL,
	[Host_Id] INT NULL,
	[Variable_Name] VARCHAR(50) NOT NULL,
	[ValueType_Code] CHAR(1) NOT NULL,
	[Variable_Value] VARBINARY(MAX) NOT NULL

	CONSTRAINT [UQ__Variables]
		UNIQUE CLUSTERED ([Server_Id], [Environment_Id], [ServerRole_Id], [Job_Id], [Host_Id], [Variable_Name]),

	CONSTRAINT [FK__Variables__Servers]
		FOREIGN KEY ([Server_Id])
		REFERENCES [Servers] ([Server_Id]) ON DELETE CASCADE,

	CONSTRAINT [FK__Variables__Environments]
		FOREIGN KEY ([Environment_Id])
		REFERENCES [Environments] ([Environment_Id]) ON DELETE CASCADE,

	CONSTRAINT [FK__Variables__ServerRoles]
		FOREIGN KEY ([ServerRole_Id])
		REFERENCES [ServerRoles] ([ServerRole_Id]) ON DELETE CASCADE,

	CONSTRAINT [FK__Variables__Jobs]
		FOREIGN KEY ([Job_Id])
		REFERENCES [Jobs] ([Job_Id]) ON DELETE CASCADE,

	CONSTRAINT [FK__Variables__Hosts]
		FOREIGN KEY ([Host_Id])
		REFERENCES [Hosts] ([Host_Id]) ON DELETE CASCADE,

	CONSTRAINT [CK__Variables__Variable_Name]
		CHECK ((LTRIM(RTRIM([Variable_Name])) = [Variable_Name]) AND ([Variable_Name] <> '')),

	CONSTRAINT [CK__Variables__ValueType_Code]
		CHECK ([ValueType_Code] IN ('S', 'V'))
)

GO

CREATE TABLE [ScopedExecutionLogs]
(
	[Execution_Id] INT NOT NULL,
	[Scope_Sequence] INT NOT NULL,
	[Parent_Scope_Sequence] INT NULL,
	[Scope_Name] VARBINARY(MAX) NOT NULL,
	[Start_Date] DATETIME NOT NULL,
	[End_Date] DATETIME NULL,
	[HighestLogEntry_Level] INT NULL,

	CONSTRAINT [PK__ScopedExecutionLogs]
		PRIMARY KEY ([Execution_Id], [Scope_Sequence]),

	CONSTRAINT [FK__ScopedExecutionLogs__Executions]
		FOREIGN KEY ([Execution_Id])
		REFERENCES [Executions] ([Execution_Id])
        ON DELETE CASCADE,

	CONSTRAINT [FK__ScopedExecutionLogs__ScopedExecutionsLogs]
		FOREIGN KEY ([Execution_Id], [Parent_Scope_Sequence])
		REFERENCES [ScopedExecutionLogs] ([Execution_Id], [Scope_Sequence]),

	CONSTRAINT [CK__ScopedExecutionLogs__Scope_Sequence]
		CHECK ([Scope_Sequence] > 0),

	CONSTRAINT [CK__ScopedExecutionLogs__Parent_Scope_Sequence]
		CHECK ([Parent_Scope_Sequence] IS NULL OR ([Parent_Scope_Sequence] <> [Scope_Sequence]))
)

CREATE TABLE [ScopedExecutionLogEntries]
(
	[Execution_Id] INT NOT NULL,
	[LogEntry_Sequence] INT NOT NULL,
	[Scope_Sequence] INT NOT NULL,
	[LogEntry_Level] INT NOT NULL,
	[LogEntry_Text] VARBINARY(MAX) NOT NULL,
	[LogEntry_Date] DATETIME NOT NULL,

	CONSTRAINT [PK__ScopedExecutionLogEntries]
		PRIMARY KEY ([Execution_Id], [LogEntry_Sequence]),

	CONSTRAINT [FK__ScopedExecutionLogEntries__ScopedExecutionLogs]
		FOREIGN KEY ([Execution_Id], [Scope_Sequence])
		REFERENCES [ScopedExecutionLogs] ([Execution_Id], [Scope_Sequence])
        ON DELETE CASCADE,

	CONSTRAINT [CK__ScopedExecutionLogEntries__LogEntry_Sequence]
		CHECK ([LogEntry_Sequence] > 0)
)

GO

CREATE TABLE [ServerConfigurations](
	[Server_Id] INT NOT NULL
		CONSTRAINT [FK__ServerConfigurations__Servers]
		FOREIGN KEY ([Server_Id])
		REFERENCES [Servers] ([Server_Id]) ON DELETE CASCADE,
	
	[ServerConfigurationType_Name] NVARCHAR(50) NOT NULL,

	[ServerConfigurationKey_Name] NVARCHAR(255) NOT NULL,

	[ServerConfiguration_Status_Code] CHAR(1) NOT NULL
	CONSTRAINT [CK__ServerConfigurations__Status_Code_Domain]
	CHECK ([ServerConfiguration_Status_Code] IN ('C','D','U')),

	[CollectedOn_Execution_Id] INT NOT NULL,

	[CollectedFor_ServerRole_Id] INT NULL,

	[RemediatedWith_Job_Id] INT NULL
	CONSTRAINT [FK__ServerConfigurations__RemediatedWith_Job_Id]
	FOREIGN KEY ([RemediatedWith_Job_Id])
	REFERENCES [Jobs] ([Job_Id])
	ON DELETE SET NULL,

	CONSTRAINT [PK__ServerConfigurations]
	PRIMARY KEY ([Server_Id],[ServerConfigurationType_Name], [ServerConfigurationKey_Name]),

	[ServerConfiguration_Configuration] XML NULL
)

GO

CREATE TABLE [Configuration]
(
	[Key_Name] VARCHAR(200) NOT NULL,
	[Value_Text] NVARCHAR(MAX) NOT NULL,

	CONSTRAINT [PK__Configuration]
		PRIMARY KEY ([Key_Name]),

	CONSTRAINT [CK__Configuration__Key_Name]
		CHECK ([Key_Name] <> '')
)

GO

CREATE TABLE [LogMessages]
(
	[LogMessage_Id] INT IDENTITY(1,1) NOT NULL,
	[Logged_Date] DATETIME NOT NULL,
	[Message_Text] VARCHAR(MAX) NOT NULL,
	[Message_Level] INT NOT NULL,
	[Category_Name] VARCHAR(30) NULL,
	[Details_Bytes] VARBINARY(MAX) NULL,
    [ShowNotification_Indicator] YNINDICATOR NOT NULL,

    [Job_Id] INT NULL,
    [Server_Id] INT NULL,
    [Environment_Id] INT NULL,

    CONSTRAINT [PK__LogMessages] PRIMARY KEY ([LogMessage_Id]),

    CONSTRAINT [FK__LogMessages__Jobs] FOREIGN KEY ([Job_Id])
               REFERENCES [Jobs] ([Job_Id])
               ON DELETE CASCADE,
    CONSTRAINT [FK__LogMessages__Servers] FOREIGN KEY ([Server_Id])
               REFERENCES [Servers] ([Server_Id])
               ON DELETE CASCADE,
    CONSTRAINT [FK__LogMessages__Environments] FOREIGN KEY ([Environment_Id])
               REFERENCES [Environments] ([Environment_Id])
               ON DELETE CASCADE
)

GO

CREATE TABLE [Users] (
	[User_Name] USERNAME NOT NULL
		CONSTRAINT [PK__Users] 
		PRIMARY KEY,
	[Display_Name] NVARCHAR(100) NOT NULL,
	[Email_Address] VARCHAR(250) NULL,
	[Salt_Bytes] BINARY(10) NULL,
	[Password_Bytes] BINARY(20) NULL,
    [ChangePasswordOnLogin_Indicator] YNINDICATOR NOT NULL
)
GO

CREATE TABLE [Groups](
	[Group_Name] NVARCHAR(50) NOT NULL,
    CONSTRAINT [PK__Groups] PRIMARY KEY ([Group_Name])
)
GO

CREATE TABLE [UserGroups](
	[User_Name] USERNAME NOT NULL,
	[Group_Name] NVARCHAR(50) NOT NULL,
   CONSTRAINT [PK__UserGroups] PRIMARY KEY ([User_Name],[Group_Name]),
   CONSTRAINT [FK__UserGroups__Groups] FOREIGN KEY([Group_Name]) REFERENCES [Groups] ([Group_Name]),
   CONSTRAINT [FK__UserGroups__Users] FOREIGN KEY([User_Name]) REFERENCES [Users] ([User_Name])
)
GO

GO

CREATE TABLE [UserDirectories]
(
	[UserDirectory_Id] INT NOT NULL,
	[UserDirectory_Name] NVARCHAR(50) NOT NULL,
	[UserDirectory_Configuration] XML NOT NULL,

	CONSTRAINT [PK__UserDirectories]
		PRIMARY KEY ([UserDirectory_Id])
)

GO

INSERT INTO [UserDirectories]
(
	[UserDirectory_Id],
	[UserDirectory_Name],
	[UserDirectory_Configuration]
)
VALUES
(
	1,
	'Built-In',
	'<Inedo.Otter.WebApplication.Security.UserDirectory.BuiltInDirectory Assembly="Otter.WebApplication"><Properties /></Inedo.Otter.WebApplication.Security.UserDirectory.BuiltInDirectory>'
)

INSERT INTO [UserDirectories]
(
	[UserDirectory_Id],
	[UserDirectory_Name],
	[UserDirectory_Configuration]
)
VALUES
(
	2,
	'LDAP',
	'<Inedo.Otter.WebApplication.Security.UserDirectory.LdapDirectory Assembly="Otter.WebApplication"><Properties /></Inedo.Otter.WebApplication.Security.UserDirectory.LdapDirectory>'
)

INSERT INTO [UserDirectories]
(
	[UserDirectory_Id],
	[UserDirectory_Name],
	[UserDirectory_Configuration]
)
VALUES
(
	3,
	'Active Directory with Multiple Domains',
	'<Inedo.Otter.WebApplication.Security.UserDirectory.MultiDomainActiveDirectory Assembly="Otter.WebApplication"><Properties /></Inedo.Otter.WebApplication.Security.UserDirectory.MultiDomainActiveDirectory>'
)

GO

CREATE TABLE [Roles]
(
	[Role_Id] INT IDENTITY(1,1) NOT NULL
		CONSTRAINT [PK__Roles]
		PRIMARY KEY NONCLUSTERED ([Role_Id]),
	[Role_Name] NVARCHAR(50) NOT NULL,
	CONSTRAINT [UQ__Roles]
		UNIQUE NONCLUSTERED ([Role_Name])
)

CREATE TABLE [Tasks]
(
	[Task_Id] INT IDENTITY(1,1) NOT NULL
		CONSTRAINT [PK__Tasks]
		PRIMARY KEY CLUSTERED ([Task_Id]),
	[Task_Name] VARCHAR(50) NOT NULL,
    [EnvironmentScopable_Indicator] YNINDICATOR NOT NULL,
	CONSTRAINT [UQ__Tasks]
		UNIQUE NONCLUSTERED ([Task_Name])
)

GO

CREATE TABLE [RoleTasks]
(
	[Role_Id] INT NOT NULL,
		CONSTRAINT [FK__RoleTasks__Roles]
		FOREIGN KEY ([Role_Id]) REFERENCES [Roles] ([Role_Id]) ON DELETE CASCADE,
	[Task_Id] INT NOT NULL,
		CONSTRAINT [FK__RoleTasks__Tasks]
		FOREIGN KEY ([Task_Id]) REFERENCES [Tasks] ([Task_Id]) ON DELETE CASCADE,
	CONSTRAINT [PK__RoleTasks]
		PRIMARY KEY ([Role_Id], [Task_Id])
)
GO

CREATE TABLE [Privileges](
	[Privilege_Id] INT IDENTITY(1,1) NOT NULL
		CONSTRAINT [PK__Privileges] 
		PRIMARY KEY NONCLUSTERED ([Privilege_Id]),
	[Principal_Name] [USERNAME] NOT NULL,
    [PrivilegeType_Code] CHAR(1) NOT NULL,
	[PrincipalType_Code] CHAR(1) NOT NULL,
	[Role_Id] INT NOT NULL,
    [Environment_Id] INT NULL,
    [UserDirectory_Id] INT NOT NULL,

	CONSTRAINT [UQ__Privileges] 
		UNIQUE NONCLUSTERED ([Principal_Name],[PrincipalType_Code],[Role_Id]),
	CONSTRAINT [CK_Privileges__PrincipalType_Code_Domain] CHECK  (([PrincipalType_Code]='G' OR [PrincipalType_Code]='U')),
    CONSTRAINT [FK__Privileges__Environments] FOREIGN KEY ([Environment_Id])
               REFERENCES [Environments] ([Environment_Id])
               ON DELETE CASCADE,

    CONSTRAINT [FK__Privileges__UserDirectories]
		FOREIGN KEY ([UserDirectory_Id])
		REFERENCES [UserDirectories] ([UserDirectory_Id])
)

GO

INSERT INTO [Rafts] VALUES ('Default', NULL, '<Inedo.Otter.Extensions.RaftRepositories.DatabaseRaftRepository Assembly="OtterCore" />')
INSERT INTO [Servers] ([Server_Name], [Host_Id], [RoutineExecutionType_Code], [Agent_Configuration], [Raft_Id], [ServerStatus_Code]) VALUES ( 'LOCALHOST' , NULL, 'C','<Inedo.Otter.Extensions.Agents.Local.LocalAgent Assembly="OtterCoreEx" />', 1, 'UNKWN' )

GO
