IF OBJECT_ID('[ServerRoles_Extended]') IS NOT NULL DROP VIEW [ServerRoles_Extended]
GO

CREATE VIEW [ServerRoles_Extended]
AS

    SELECT
           SR.[ServerRole_Id]
          ,SR.[ServerRole_Name]
          ,SR.[Description_Text]
          ,[Servers_Count] = (SELECT COUNT(*)
                                FROM [ServerRoleServers] SRS 
                               WHERE SRS.[ServerRole_Id] = SR.[ServerRole_Id])

          ,[Environments_Count] = (SELECT COUNT([Environment_Id]) 
                                     FROM [ServerRoleServers] SRS 
                                INNER JOIN [EnvironmentServers] ES
                                        ON ES.[Server_Id] = SRS.[Server_Id]
                                    WHERE SR.[ServerRole_Id] = SRS.[ServerRole_Id])
                                    
          
          ,[Aggregate_ServerConfiguration_Status_Code] = COALESCE((
                SELECT TOP 1 SC.[ServerConfiguration_Status_Code]
                  FROM [ServerConfigurations] SC
                 WHERE SC.[CollectedFor_ServerRole_Id] = SR.[ServerRole_Id] 
                 ORDER BY CHARINDEX(SC.[ServerConfiguration_Status_Code], 'DC')
            ), 'U')

          ,[Aggregate_Latest_CollectionRun_ExecutionStatus_Code] = E_BYSTATUS.[ExecutionStatus_Code]
          ,[Aggregate_Latest_CollectionRun_Execution_Id] = E_BYSTATUS.[Execution_Id]
          ,[Aggregate_Latest_CollectionRun_Start_Date] = E_BYSTATUS.[Start_Date]
           ,[AllDriftPendingRemediation_Indicator] =  CASE 
              WHEN EXISTS(SELECT * FROM [ServerConfigurations] _SC 
                          INNER JOIN [ServerRoleServers] SRS
                             ON _SC.[Server_Id] = SRS.[Server_Id]
			               WHERE [ServerConfiguration_Status_Code] = 'D') 
                   AND 
                   NOT EXISTS(SELECT * FROM [ServerConfigurations] _SC 
                          INNER JOIN [ServerRoleServers] SRS
                             ON _SC.[Server_Id] = SRS.[Server_Id]
			               WHERE [ServerConfiguration_Status_Code] = 'D'
                             AND [RemediatedWith_Job_Id] IS NULL) THEN 'Y'
              ELSE 'N' END

           ,SR.[Raft_Id]
		   ,R.[Raft_Name]

		   ,SR.[CollectOperations_Csv]

	  FROM [ServerRoles] SR
	       LEFT JOIN [Rafts] R
	              ON R.[Raft_Id] = SR.[Raft_Id]

OUTER APPLY (
    SELECT TOP 1 E.*
        FROM [Executions] E
            INNER JOIN (SELECT [Server_Id], [Execution_Id] = MAX([Execution_Id]) 
                            FROM [Executions]
                        GROUP BY [Server_Id]) E_LATEST
                    ON E.[Execution_Id] = E_LATEST.[Execution_Id]
            INNER JOIN [ServerRoleServers] _SRS
                    ON E.[Server_Id] = _SRS.[Server_Id]
        WHERE _SRS.[ServerRole_Id] = SR.[ServerRole_Id]
        ORDER BY CHARINDEX(E.[ExecutionStatus_Code], 'EWS')
) E_BYSTATUS

GO
