EXEC [dbo].[__AddStoredProcInfo]
    /* StoredProc_Name         */ 'Jobs_UpdateRecurringJob',
    /* Internal_Indicator      */ 'Y',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Updates the specified recurring job.'
GO


IF OBJECT_ID('[Jobs_UpdateRecurringJob]') IS NOT NULL DROP PROCEDURE [Jobs_UpdateRecurringJob]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Jobs_UpdateRecurringJob]
(
    @Job_Id INT,
    @Plan_Name NVARCHAR(50) = NULL,
    @Raft_Id INT = NULL,
    @Schedule_Id INT = NULL,
    @Job_Name NVARCHAR(50) = NULL,
    @LastRun_Date DATETIME = NULL,
    @SetDisabled_Indicator YNINDICATOR = NULL
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION
    
	UPDATE [Jobs]
       SET [Plan_Name] = COALESCE(@Plan_Name, [Plan_Name]),
           [Raft_Id] = COALESCE(@Raft_Id, [Raft_Id]),
           [Schedule_Id] = COALESCE(@Schedule_Id, [Schedule_Id]),
           [Job_Name] = COALESCE(@Job_Name, [Job_Name]),
           [LastRun_Date] = COALESCE(@LastRun_Date, [LastRun_Date]),
           [JobState_Code] = CASE 
                                WHEN @SetDisabled_Indicator = 'Y' THEN 'D'
                                WHEN @SetDisabled_Indicator = 'N' THEN 'P'
                                ELSE [JobState_Code]
                             END
     WHERE [Job_Id] = @Job_Id

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH


END
GO

GRANT EXECUTE ON [Jobs_UpdateRecurringJob] TO [OtterUser_Role]
