EXEC [dbo].[__AddStoredProcInfo]
    /* StoredProc_Name         */ 'Rafts_CreateOrUpdateRaft',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ 'Raft_Id',
    /* Description_Text        */ 'Creates a new server Raft, or updates an existing one.'
GO

IF OBJECT_ID('[Rafts_CreateOrUpdateRaft]') IS NOT NULL DROP PROCEDURE [Rafts_CreateOrUpdateRaft]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Rafts_CreateOrUpdateRaft]
(
    @Raft_Name NVARCHAR(50),
    @Environment_Id INT,
    @Raft_Configuration XML,
	@RestrictToPipelineRafts_Indicator YNINDICATOR,
    @Raft_Id INT = NULL OUT
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	IF (@Raft_Id IS NULL)
	BEGIN
		INSERT INTO [Rafts] 
		(
			[Raft_Name],
			[Environment_Id],
            [Raft_Configuration],
			[RestrictToPipelineRafts_Indicator]
		)
		VALUES
		(
            @Raft_Name,
			@Environment_Id,
            @Raft_Configuration,
			@RestrictToPipelineRafts_Indicator
		)
		SET @Raft_Id = SCOPE_IDENTITY()

		-- EXEC [Events_RaiseEvent] 'ENVNWS', NULL, @Server_Id
	END
	ELSE
	BEGIN
		UPDATE [Rafts]
		   SET [Raft_Name] = @Raft_Name,
		       [Environment_Id] = @Environment_Id,
			   [Raft_Configuration] = @Raft_Configuration,
			   [RestrictToPipelineRafts_Indicator] = @RestrictToPipelineRafts_Indicator
		 WHERE [Raft_Id] = @Raft_Id

		--EXEC [Events_RaiseEvent] 'ENVMDS', NULL, @Server_Id
	END

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH


END
GO

GRANT EXECUTE ON [Rafts_CreateOrUpdateRaft] TO [OtterUser_Role]
