EXEC [dbo].[__AddStoredProcInfo]
    /* StoredProc_Name         */ 'Servers_CreateOrUpdateConfiguration',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Creates a new server configuration, or updates an existing one.'
GO


IF OBJECT_ID('[Servers_CreateOrUpdateConfiguration]') IS NOT NULL DROP PROCEDURE [Servers_CreateOrUpdateConfiguration]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Servers_CreateOrUpdateConfiguration]
(
    @Server_Id INT,
    @ServerConfigurationType_Name NVARCHAR(50),
    @ServerConfigurationKey_Name NVARCHAR(255),
    @CollectedOn_Execution_Id INT,
    @CollectedFor_ServerRole_Id INT,
    @ServerConfiguration_Status_Code CHAR(1),
    @ServerConfiguration_Configuration XML
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
    BEGIN TRANSACTION

    IF EXISTS(SELECT * 
                FROM [ServerConfigurations] 
               WHERE [Server_Id] = @Server_Id
                 AND [ServerConfigurationType_Name] = @ServerConfigurationType_Name
                 AND [ServerConfigurationKey_Name] = @ServerConfigurationKey_Name)
    BEGIN

        UPDATE [ServerConfigurations]
           SET [ServerConfiguration_Configuration] = @ServerConfiguration_Configuration,
               [CollectedOn_Execution_Id] = @CollectedOn_Execution_Id,
               [ServerConfiguration_Status_Code] = @ServerConfiguration_Status_Code,
               [CollectedFor_ServerRole_Id] = @CollectedFor_ServerRole_Id,
               [RemediatedWith_Job_Id] = CASE 
                                            WHEN @ServerConfiguration_Status_Code = 'C' THEN NULL 
                                            ELSE [RemediatedWith_Job_Id] 
                                          END
         WHERE [Server_Id] = @Server_Id
           AND [ServerConfigurationType_Name] = @ServerConfigurationType_Name
           AND [ServerConfigurationKey_Name] = @ServerConfigurationKey_Name

    END
    ELSE
    BEGIN

        INSERT INTO [ServerConfigurations] 
        (
            [Server_Id],
            [ServerConfigurationType_Name],
            [ServerConfigurationKey_Name],
            [ServerConfiguration_Configuration],
            [CollectedOn_Execution_Id],
            [CollectedFor_ServerRole_Id],
            [ServerConfiguration_Status_Code]
        )
        VALUES
        (
            @Server_Id,
            @ServerConfigurationType_Name,
            @ServerConfigurationKey_Name,
            @ServerConfiguration_Configuration,
            @CollectedOn_Execution_Id,
            @CollectedFor_ServerRole_Id,
            @ServerConfiguration_Status_Code
        )

    END

    COMMIT
END TRY BEGIN CATCH
    IF XACT_STATE()<>0 ROLLBACK
    EXEC [HandleError]
END CATCH


END
GO

GRANT EXECUTE ON [Servers_CreateOrUpdateConfiguration] TO [OtterUser_Role]
