EXEC [__AddStoredProcInfo]
    /* StoredProc_Name         */ 'UserDirectories_CreateOrUpdateDirectory',
    /* Internal_Indicator      */ 'Y',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ 'UserDirectory_Id',
    /* Description_Text        */ 'Creates a new user directory or updates an existing one.'
GO

IF OBJECT_ID('[UserDirectories_CreateOrUpdateDirectory]') IS NOT NULL DROP PROCEDURE [UserDirectories_CreateOrUpdateDirectory]
GO

SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO

CREATE PROCEDURE [UserDirectories_CreateOrUpdateDirectory]
(
	@UserDirectory_Name NVARCHAR(50),
	@UserDirectory_Configuration XML,
	@UserDirectory_Id INT = NULL OUT
)
AS
BEGIN

SET NOCOUNT ON
SET QUOTED_IDENTIFIER ON

BEGIN TRY
	BEGIN TRANSACTION

	IF @UserDirectory_Id IS NULL
	BEGIN

		SET @UserDirectory_Id = COALESCE((SELECT MAX([UserDirectory_Id]) FROM [UserDirectories]), 0) + 1

		INSERT INTO [UserDirectories]
		(
			[UserDirectory_Id],
			[UserDirectory_Name],
			[UserDirectory_Configuration]
		)
		VALUES
		(
			@UserDirectory_Id,
			@UserDirectory_Name,
			@UserDirectory_Configuration
		)

	END
	ELSE
	BEGIN

		UPDATE [UserDirectories]
		   SET [UserDirectory_Name] = @UserDirectory_Name,
		       [UserDirectory_Configuration] = @UserDirectory_Configuration
		 WHERE [UserDirectory_Id] = @UserDirectory_Id

	END

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH


END
GO

GRANT EXECUTE ON [UserDirectories_CreateOrUpdateDirectory] TO [OtterUser_Role]